@@ -37,10 +37,10 @@ class Pic:
         :return: 成功 1, 失败 0
         """
         dm_ret = self.__dm_obj.FindPic(int_x1, int_y1, int_x2, int_y2, pic_name, delta_color, sim, direct)
-        if dm_ret[-1] == -1:
+        if dm_ret[2] == -1:
             return
         else:
             int_x = dm_ret[1]
-            int_y = dm_ret[-1]
+            int_y = dm_ret[2]
             Mouse(self.__dm_obj).move_lClick(int_x, int_y)
             return 1
